@@ -2,10 +2,10 @@
 
 #
 # DaVinci Resolve Multi Debian package creator
-# Release 2020-11-09
+# Release 2020-12-07
 # By Daniel Tufvesson
 #
-MAKERESOLVEDEB_VERSION=1.4.0
+MAKERESOLVEDEB_VERSION=1.4.1
 
 check_command() {
     echo -n "Checking for ${1}..."
@@ -358,6 +358,11 @@ process17() {
     create_directory ${DEB_DIR}/lib/udev/rules.d
     cat > ${DEB_DIR}/lib/udev/rules.d/75-davincipanel.rules <<EOF
 SUBSYSTEM=="usb", ENV{DEVTYPE}=="usb_device", ATTRS{idVendor}=="1edb", MODE="0666"
+EOF
+    cat > ${DEB_DIR}/lib/udev/rules.d/75-davincikb.rules <<EOF
+SUBSYSTEMS=="usb", ENV{.LOCAL_ifNum}="$attr{bInterfaceNumber}"
+SUBSYSTEM=="hidraw", KERNEL=="hidraw*", ATTRS{idVendor}=="1edb", ATTRS{idProduct}=="da0b", ENV{.LOCAL_ifNum}=="04", MODE="0666"
+SUBSYSTEM=="hidraw", KERNEL=="hidraw*", ATTRS{idVendor}=="1edb", ATTRS{idProduct}=="da0e", ENV{.LOCAL_ifNum}=="02", MODE="0666"
 EOF
     cat > ${DEB_DIR}/lib/udev/rules.d/75-sdx.rules <<EOF
 SUBSYSTEM=="usb", ENV{DEVTYPE}=="usb_device", ATTRS{idVendor}=="096e", MODE="0666"
